summaryrefslogtreecommitdiff
path: root/boost/asio/io_context_strand.hpp
diff options
context:
space:
mode:
authorDongHun Kwak <dh0128.kwak@samsung.com>2019-12-05 15:12:59 +0900
committerDongHun Kwak <dh0128.kwak@samsung.com>2019-12-05 15:12:59 +0900
commitb8cf34c691623e4ec329053cbbf68522a855882d (patch)
tree34da08632a99677f6b79ecb65e5b655a5b69a67f /boost/asio/io_context_strand.hpp
parent3fdc3e5ee96dca5b11d1694975a65200787eab86 (diff)
downloadboost-b8cf34c691623e4ec329053cbbf68522a855882d.tar.gz
boost-b8cf34c691623e4ec329053cbbf68522a855882d.tar.bz2
boost-b8cf34c691623e4ec329053cbbf68522a855882d.zip
Imported Upstream version 1.67.0upstream/1.67.0
Diffstat (limited to 'boost/asio/io_context_strand.hpp')
-rw-r--r--boost/asio/io_context_strand.hpp28
1 files changed, 15 insertions, 13 deletions
diff --git a/boost/asio/io_context_strand.hpp b/boost/asio/io_context_strand.hpp
index 2190a7b7db..144e308a21 100644
--- a/boost/asio/io_context_strand.hpp
+++ b/boost/asio/io_context_strand.hpp
@@ -2,7 +2,7 @@
// io_context_strand.hpp
// ~~~~~~~~~~~~~~~~~~~~~
//
-// Copyright (c) 2003-2017 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2018 Christopher M. Kohlhoff (chris at kohlhoff dot com)
//
// Distributed under the Boost Software License, Version 1.0. (See accompanying
// file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -212,15 +212,16 @@ public:
* handler object as required. The function signature of the handler must be:
* @code void handler(); @endcode
*/
- template <typename CompletionHandler>
- BOOST_ASIO_INITFN_RESULT_TYPE(CompletionHandler, void ())
- dispatch(BOOST_ASIO_MOVE_ARG(CompletionHandler) handler)
+ template <typename LegacyCompletionHandler>
+ BOOST_ASIO_INITFN_RESULT_TYPE(LegacyCompletionHandler, void ())
+ dispatch(BOOST_ASIO_MOVE_ARG(LegacyCompletionHandler) handler)
{
// If you get an error on the following line it means that your handler does
- // not meet the documented type requirements for a CompletionHandler.
- BOOST_ASIO_COMPLETION_HANDLER_CHECK(CompletionHandler, handler) type_check;
+ // not meet the documented type requirements for a LegacyCompletionHandler.
+ BOOST_ASIO_LEGACY_COMPLETION_HANDLER_CHECK(
+ LegacyCompletionHandler, handler) type_check;
- async_completion<CompletionHandler, void ()> init(handler);
+ async_completion<LegacyCompletionHandler, void ()> init(handler);
service_.dispatch(impl_, init.completion_handler);
@@ -266,15 +267,16 @@ public:
* handler object as required. The function signature of the handler must be:
* @code void handler(); @endcode
*/
- template <typename CompletionHandler>
- BOOST_ASIO_INITFN_RESULT_TYPE(CompletionHandler, void ())
- post(BOOST_ASIO_MOVE_ARG(CompletionHandler) handler)
+ template <typename LegacyCompletionHandler>
+ BOOST_ASIO_INITFN_RESULT_TYPE(LegacyCompletionHandler, void ())
+ post(BOOST_ASIO_MOVE_ARG(LegacyCompletionHandler) handler)
{
// If you get an error on the following line it means that your handler does
- // not meet the documented type requirements for a CompletionHandler.
- BOOST_ASIO_COMPLETION_HANDLER_CHECK(CompletionHandler, handler) type_check;
+ // not meet the documented type requirements for a LegacyCompletionHandler.
+ BOOST_ASIO_LEGACY_COMPLETION_HANDLER_CHECK(
+ LegacyCompletionHandler, handler) type_check;
- async_completion<CompletionHandler, void ()> init(handler);
+ async_completion<LegacyCompletionHandler, void ()> init(handler);
service_.post(impl_, init.completion_handler);